﻿using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Mirea.Api.Security.Common.Interfaces;
using Mirea.Api.Security.Services;
using System;

namespace Mirea.Api.Security;

public static class DependencyInjection
{
    public static IServiceCollection AddSecurityServices(this IServiceCollection services, IConfiguration configuration)
    {
        var saltSize = int.Parse(configuration["SECURITY_SALT_SIZE"]!);
        var hashSize = int.Parse(configuration["SECURITY_HASH_SIZE"]!);
        var iteration = int.Parse(configuration["SECURITY_HASH_ITERATION"]!);
        var memory = int.Parse(configuration["SECURITY_HASH_MEMORY"]!);
        var parallelism = int.Parse(configuration["SECURITY_HASH_PARALLELISM"]!);

        services.AddSingleton(new PasswordHashService
        {
            SaltSize = saltSize,
            HashSize = hashSize,
            Iterations = iteration,
            Memory = memory,
            Parallelism = parallelism,
            Secret = configuration["SECURITY_HASH_TOKEN"]
        });

        var lifeTimePreAuthToken = TimeSpan.FromMinutes(int.Parse(configuration["SECURITY_LIFE_TIME_1_FA"]!));

        services.AddSingleton(provider =>
        {
            var cache = provider.GetRequiredService<ICacheService>();

            return new PreAuthService(cache)
            {
                Lifetime = lifeTimePreAuthToken
            };
        });

        var lifeTimeRefreshToken = TimeSpan.FromMinutes(int.Parse(configuration["SECURITY_LIFE_TIME_RT"]!));

        services.AddSingleton(provider =>
        {
            var cacheService = provider.GetRequiredService<ICacheService>();
            var accessTokenService = provider.GetRequiredService<IAccessToken>();
            var revokedTokenService = provider.GetRequiredService<IRevokedToken>();

            return new AuthService(cacheService, accessTokenService, revokedTokenService)
            {
                Lifetime = lifeTimeRefreshToken
            };
        });

        return services;
    }
}