﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Mysql.Schedule;

public class GroupConfiguration : IEntityTypeConfiguration<Group>
{
    public void Configure(EntityTypeBuilder<Group> builder)
    {
        builder.ToTable(nameof(Group));
        builder.HasKey(g => g.Id);
        builder.HasIndex(g => g.Id).IsUnique();
        builder.Property(g => g.Id).HasColumnType("INT").IsRequired().ValueGeneratedOnAdd();

        builder.Property(g => g.FacultyId).HasColumnType("INT");
        builder.Property(g => g.Name).HasColumnType("VARCHAR(64)").IsRequired().HasMaxLength(64);

        builder
            .HasOne(g => g.Faculty)
            .WithMany(u => u.Groups)
            .HasForeignKey(d => d.FacultyId)
            .OnDelete(DeleteBehavior.SetNull);
    }
}