﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Mysql.Schedule;

public class LessonConfiguration : IEntityTypeConfiguration<Lesson>
{
    public void Configure(EntityTypeBuilder<Lesson> builder)
    {
        builder.ToTable(nameof(Lesson));
        builder.HasKey(l => l.Id);
        builder.HasIndex(l => l.Id).IsUnique();
        builder.Property(l => l.Id).HasColumnType("INT").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.IsEven).HasColumnType("BIT(1)").IsRequired();
        builder.Property(l => l.DayOfWeek).HasColumnType("INT").IsRequired();
        builder.Property(l => l.PairNumber).HasColumnType("INT").IsRequired();
        builder.Property(l => l.IsExcludedWeeks).HasColumnType("BIT(1)");

        builder.Property(l => l.GroupId).HasColumnType("INT").IsRequired();
        builder.Property(l => l.DisciplineId).HasColumnType("INT").IsRequired();

        builder
            .HasOne(l => l.Group)
            .WithMany(g => g.Lessons)
            .HasForeignKey(d => d.GroupId)
            .OnDelete(DeleteBehavior.Cascade);

        builder
            .HasOne(l => l.Discipline)
            .WithMany(d => d.Lessons)
            .HasForeignKey(l => l.DisciplineId)
            .OnDelete(DeleteBehavior.Cascade);
    }
}