﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Postgresql.Schedule;

public class LessonAssociationConfiguration : IEntityTypeConfiguration<LessonAssociation>
{
    public void Configure(EntityTypeBuilder<LessonAssociation> builder)
    {
        builder.ToTable(nameof(LessonAssociation));
        builder.HasKey(l => l.Id);
        builder.HasIndex(l => l.Id).IsUnique();
        builder.Property(l => l.Id).HasColumnType("serial").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.LinkToMeet).HasColumnType("text").HasMaxLength(512);

        builder.Property(l => l.LessonId).HasColumnType("serial").IsRequired();
        builder.Property(l => l.ProfessorId).HasColumnType("serial");
        builder.Property(l => l.LectureHallId).HasColumnType("serial");
        builder.Property(l => l.TypeOfOccupationId).HasColumnType("serial").IsRequired();


        builder
            .HasOne(l => l.Lesson)
            .WithMany(d => d.LessonAssociations)
            .HasForeignKey(l => l.LessonId)
            .OnDelete(DeleteBehavior.Cascade);

        builder
            .HasOne(l => l.Professor)
            .WithMany(p => p.LessonAssociations)
            .HasForeignKey(l => l.ProfessorId)
            .OnDelete(DeleteBehavior.SetNull);

        builder
            .HasOne(l => l.LectureHall)
            .WithMany(l => l.LessonAssociations)
            .HasForeignKey(l => l.LectureHallId)
            .OnDelete(DeleteBehavior.SetNull);

        builder
            .HasOne(l => l.TypeOfOccupation)
            .WithMany(t => t.Lessons)
            .HasForeignKey(d => d.TypeOfOccupationId)
            .OnDelete(DeleteBehavior.Cascade);
    }
}