﻿using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using Mirea.Api.DataAccess.Domain.Schedule;

namespace Mirea.Api.DataAccess.Persistence.EntityTypeConfigurations.Postgresql.Schedule;

public class LessonConfiguration : IEntityTypeConfiguration<Lesson>
{
    public void Configure(EntityTypeBuilder<Lesson> builder)
    {
        builder.ToTable(nameof(Lesson));
        builder.HasKey(l => l.Id);
        builder.HasIndex(l => l.Id).IsUnique();
        builder.Property(l => l.Id).HasColumnType("serial").IsRequired().ValueGeneratedOnAdd();

        builder.Property(l => l.IsEven).HasColumnType("boolean").IsRequired();
        builder.Property(l => l.DayOfWeek).HasColumnType("serial").IsRequired();
        builder.Property(l => l.PairNumber).HasColumnType("serial").IsRequired();
        builder.Property(l => l.IsExcludedWeeks).HasColumnType("boolean");

        builder.Property(l => l.GroupId).HasColumnType("serial").IsRequired();
        builder.Property(l => l.DisciplineId).HasColumnType("serial").IsRequired();

        builder
            .HasOne(l => l.Group)
            .WithMany(g => g.Lessons)
            .HasForeignKey(d => d.GroupId)
            .OnDelete(DeleteBehavior.Cascade);

        builder
            .HasOne(l => l.Discipline)
            .WithMany(d => d.Lessons)
            .HasForeignKey(l => l.DisciplineId)
            .OnDelete(DeleteBehavior.Cascade);
    }
}